@@ -1,10 +1,11 @@
-# sharpapi/dto/__init__.py
+# src/sharpapi/dto/__init__.py
 
-"""
-Data Transfer Objects (DTO) Package Initialization
-"""
-
-# Import DTO classes for easy access
 from .job_description_parameters import JobDescriptionParameters
 from .sharp_api_job import SharpApiJob
 from .sharp_api_subscription_info import SharpApiSubscriptionInfo
+
+__all__ = [
+    "JobDescriptionParameters",
+    "SharpApiJob",
+    "SharpApiSubscriptionInfo",
+]
